@@ -41,8 +41,7 @@ import abc
 import copy
 
 from oslo_utils import strutils
-import six
-from six.moves.urllib import parse
+from urllib import parse
 
 from searchlightclient.common import exceptions
 from searchlightclient.i18n import _
@@ -224,8 +223,7 @@ class BaseManager(HookableMixin):
         return self.client.delete(url)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ManagerWithFind(BaseManager):
+class ManagerWithFind(BaseManager, metaclass=abc.ABCMeta):
     """Manager with additional `find()`/`findall()` methods."""
 
     @abc.abstractmethod
